# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BackendConfigAcmeArgs', 'BackendConfigAcme']

@pulumi.input_type
class BackendConfigAcmeArgs:
    def __init__(__self__, *,
                 backend: pulumi.Input[_builtins.str],
                 enabled: pulumi.Input[_builtins.bool],
                 allow_role_ext_key_usage: Optional[pulumi.Input[_builtins.bool]] = None,
                 allowed_issuers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 default_directory_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
                 eab_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a BackendConfigAcme resource.
        :param pulumi.Input[_builtins.str] backend: The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether ACME is enabled.
        :param pulumi.Input[_builtins.bool] allow_role_ext_key_usage: Specifies whether the ExtKeyUsage field from a role is used. **Vault 1.14.1+**
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_issuers: Specifies which issuers are allowed for use with ACME.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_roles: Specifies which roles are allowed for use with ACME.
        :param pulumi.Input[_builtins.str] default_directory_policy: Specifies the policy to be used for non-role-qualified ACME requests.
               Allowed values are `forbid`, `sign-verbatim`, `role:<role_name>`, `external-policy` or `external-policy:<policy>`.
        :param pulumi.Input[_builtins.str] dns_resolver: DNS resolver to use for domain resolution on this mount.
               Must be in the format `<host>:<port>`, with both parts mandatory.
        :param pulumi.Input[_builtins.str] eab_policy: Specifies the policy to use for external account binding behaviour.
               Allowed values are `not-required`, `new-account-required` or `always-required`.
        :param pulumi.Input[_builtins.int] max_ttl: The maximum TTL in seconds for certificates issued by ACME. **Vault 1.17.0+**
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        """
        pulumi.set(__self__, "backend", backend)
        pulumi.set(__self__, "enabled", enabled)
        if allow_role_ext_key_usage is not None:
            pulumi.set(__self__, "allow_role_ext_key_usage", allow_role_ext_key_usage)
        if allowed_issuers is not None:
            pulumi.set(__self__, "allowed_issuers", allowed_issuers)
        if allowed_roles is not None:
            pulumi.set(__self__, "allowed_roles", allowed_roles)
        if default_directory_policy is not None:
            pulumi.set(__self__, "default_directory_policy", default_directory_policy)
        if dns_resolver is not None:
            pulumi.set(__self__, "dns_resolver", dns_resolver)
        if eab_policy is not None:
            pulumi.set(__self__, "eab_policy", eab_policy)
        if max_ttl is not None:
            pulumi.set(__self__, "max_ttl", max_ttl)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> pulumi.Input[_builtins.str]:
        """
        The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Specifies whether ACME is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="allowRoleExtKeyUsage")
    def allow_role_ext_key_usage(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether the ExtKeyUsage field from a role is used. **Vault 1.14.1+**
        """
        return pulumi.get(self, "allow_role_ext_key_usage")

    @allow_role_ext_key_usage.setter
    def allow_role_ext_key_usage(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_role_ext_key_usage", value)

    @_builtins.property
    @pulumi.getter(name="allowedIssuers")
    def allowed_issuers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies which issuers are allowed for use with ACME.
        """
        return pulumi.get(self, "allowed_issuers")

    @allowed_issuers.setter
    def allowed_issuers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_issuers", value)

    @_builtins.property
    @pulumi.getter(name="allowedRoles")
    def allowed_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies which roles are allowed for use with ACME.
        """
        return pulumi.get(self, "allowed_roles")

    @allowed_roles.setter
    def allowed_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_roles", value)

    @_builtins.property
    @pulumi.getter(name="defaultDirectoryPolicy")
    def default_directory_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the policy to be used for non-role-qualified ACME requests.
        Allowed values are `forbid`, `sign-verbatim`, `role:<role_name>`, `external-policy` or `external-policy:<policy>`.
        """
        return pulumi.get(self, "default_directory_policy")

    @default_directory_policy.setter
    def default_directory_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_directory_policy", value)

    @_builtins.property
    @pulumi.getter(name="dnsResolver")
    def dns_resolver(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DNS resolver to use for domain resolution on this mount.
        Must be in the format `<host>:<port>`, with both parts mandatory.
        """
        return pulumi.get(self, "dns_resolver")

    @dns_resolver.setter
    def dns_resolver(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dns_resolver", value)

    @_builtins.property
    @pulumi.getter(name="eabPolicy")
    def eab_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the policy to use for external account binding behaviour.
        Allowed values are `not-required`, `new-account-required` or `always-required`.
        """
        return pulumi.get(self, "eab_policy")

    @eab_policy.setter
    def eab_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eab_policy", value)

    @_builtins.property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum TTL in seconds for certificates issued by ACME. **Vault 1.17.0+**
        """
        return pulumi.get(self, "max_ttl")

    @max_ttl.setter
    def max_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_ttl", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)


@pulumi.input_type
class _BackendConfigAcmeState:
    def __init__(__self__, *,
                 allow_role_ext_key_usage: Optional[pulumi.Input[_builtins.bool]] = None,
                 allowed_issuers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 default_directory_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
                 eab_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering BackendConfigAcme resources.
        :param pulumi.Input[_builtins.bool] allow_role_ext_key_usage: Specifies whether the ExtKeyUsage field from a role is used. **Vault 1.14.1+**
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_issuers: Specifies which issuers are allowed for use with ACME.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_roles: Specifies which roles are allowed for use with ACME.
        :param pulumi.Input[_builtins.str] backend: The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.str] default_directory_policy: Specifies the policy to be used for non-role-qualified ACME requests.
               Allowed values are `forbid`, `sign-verbatim`, `role:<role_name>`, `external-policy` or `external-policy:<policy>`.
        :param pulumi.Input[_builtins.str] dns_resolver: DNS resolver to use for domain resolution on this mount.
               Must be in the format `<host>:<port>`, with both parts mandatory.
        :param pulumi.Input[_builtins.str] eab_policy: Specifies the policy to use for external account binding behaviour.
               Allowed values are `not-required`, `new-account-required` or `always-required`.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether ACME is enabled.
        :param pulumi.Input[_builtins.int] max_ttl: The maximum TTL in seconds for certificates issued by ACME. **Vault 1.17.0+**
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        """
        if allow_role_ext_key_usage is not None:
            pulumi.set(__self__, "allow_role_ext_key_usage", allow_role_ext_key_usage)
        if allowed_issuers is not None:
            pulumi.set(__self__, "allowed_issuers", allowed_issuers)
        if allowed_roles is not None:
            pulumi.set(__self__, "allowed_roles", allowed_roles)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if default_directory_policy is not None:
            pulumi.set(__self__, "default_directory_policy", default_directory_policy)
        if dns_resolver is not None:
            pulumi.set(__self__, "dns_resolver", dns_resolver)
        if eab_policy is not None:
            pulumi.set(__self__, "eab_policy", eab_policy)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if max_ttl is not None:
            pulumi.set(__self__, "max_ttl", max_ttl)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)

    @_builtins.property
    @pulumi.getter(name="allowRoleExtKeyUsage")
    def allow_role_ext_key_usage(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether the ExtKeyUsage field from a role is used. **Vault 1.14.1+**
        """
        return pulumi.get(self, "allow_role_ext_key_usage")

    @allow_role_ext_key_usage.setter
    def allow_role_ext_key_usage(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_role_ext_key_usage", value)

    @_builtins.property
    @pulumi.getter(name="allowedIssuers")
    def allowed_issuers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies which issuers are allowed for use with ACME.
        """
        return pulumi.get(self, "allowed_issuers")

    @allowed_issuers.setter
    def allowed_issuers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_issuers", value)

    @_builtins.property
    @pulumi.getter(name="allowedRoles")
    def allowed_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies which roles are allowed for use with ACME.
        """
        return pulumi.get(self, "allowed_roles")

    @allowed_roles.setter
    def allowed_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_roles", value)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter(name="defaultDirectoryPolicy")
    def default_directory_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the policy to be used for non-role-qualified ACME requests.
        Allowed values are `forbid`, `sign-verbatim`, `role:<role_name>`, `external-policy` or `external-policy:<policy>`.
        """
        return pulumi.get(self, "default_directory_policy")

    @default_directory_policy.setter
    def default_directory_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_directory_policy", value)

    @_builtins.property
    @pulumi.getter(name="dnsResolver")
    def dns_resolver(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DNS resolver to use for domain resolution on this mount.
        Must be in the format `<host>:<port>`, with both parts mandatory.
        """
        return pulumi.get(self, "dns_resolver")

    @dns_resolver.setter
    def dns_resolver(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dns_resolver", value)

    @_builtins.property
    @pulumi.getter(name="eabPolicy")
    def eab_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the policy to use for external account binding behaviour.
        Allowed values are `not-required`, `new-account-required` or `always-required`.
        """
        return pulumi.get(self, "eab_policy")

    @eab_policy.setter
    def eab_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eab_policy", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether ACME is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum TTL in seconds for certificates issued by ACME. **Vault 1.17.0+**
        """
        return pulumi.get(self, "max_ttl")

    @max_ttl.setter
    def max_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_ttl", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)


@pulumi.type_token("vault:pkiSecret/backendConfigAcme:BackendConfigAcme")
class BackendConfigAcme(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_role_ext_key_usage: Optional[pulumi.Input[_builtins.bool]] = None,
                 allowed_issuers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 default_directory_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
                 eab_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Allows setting the ACME server configuration used by specified mount.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        pki = vault.Mount("pki",
            path="pki",
            type="pki",
            default_lease_ttl_seconds=3600,
            max_lease_ttl_seconds=86400)
        pki_config_cluster = vault.pkisecret.BackendConfigCluster("pki_config_cluster",
            backend=pki.path,
            path="http://127.0.0.1:8200/v1/pki",
            aia_path="http://127.0.0.1:8200/v1/pki")
        example = vault.pkisecret.BackendConfigAcme("example",
            backend=pki.path,
            enabled=True,
            allowed_issuers=["*"],
            allowed_roles=["*"],
            allow_role_ext_key_usage=False,
            default_directory_policy="sign-verbatim",
            dns_resolver="",
            eab_policy="not-required")
        ```

        ## Import

        The ACME configuration can be imported using the resource's `id`.
        In the case of the example above the `id` would be `pki/config/acme`,
        where the `pki` component is the resource's `backend`, e.g.

        ```sh
        $ pulumi import vault:pkiSecret/backendConfigAcme:BackendConfigAcme example pki/config/acme
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_role_ext_key_usage: Specifies whether the ExtKeyUsage field from a role is used. **Vault 1.14.1+**
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_issuers: Specifies which issuers are allowed for use with ACME.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_roles: Specifies which roles are allowed for use with ACME.
        :param pulumi.Input[_builtins.str] backend: The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.str] default_directory_policy: Specifies the policy to be used for non-role-qualified ACME requests.
               Allowed values are `forbid`, `sign-verbatim`, `role:<role_name>`, `external-policy` or `external-policy:<policy>`.
        :param pulumi.Input[_builtins.str] dns_resolver: DNS resolver to use for domain resolution on this mount.
               Must be in the format `<host>:<port>`, with both parts mandatory.
        :param pulumi.Input[_builtins.str] eab_policy: Specifies the policy to use for external account binding behaviour.
               Allowed values are `not-required`, `new-account-required` or `always-required`.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether ACME is enabled.
        :param pulumi.Input[_builtins.int] max_ttl: The maximum TTL in seconds for certificates issued by ACME. **Vault 1.17.0+**
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BackendConfigAcmeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Allows setting the ACME server configuration used by specified mount.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        pki = vault.Mount("pki",
            path="pki",
            type="pki",
            default_lease_ttl_seconds=3600,
            max_lease_ttl_seconds=86400)
        pki_config_cluster = vault.pkisecret.BackendConfigCluster("pki_config_cluster",
            backend=pki.path,
            path="http://127.0.0.1:8200/v1/pki",
            aia_path="http://127.0.0.1:8200/v1/pki")
        example = vault.pkisecret.BackendConfigAcme("example",
            backend=pki.path,
            enabled=True,
            allowed_issuers=["*"],
            allowed_roles=["*"],
            allow_role_ext_key_usage=False,
            default_directory_policy="sign-verbatim",
            dns_resolver="",
            eab_policy="not-required")
        ```

        ## Import

        The ACME configuration can be imported using the resource's `id`.
        In the case of the example above the `id` would be `pki/config/acme`,
        where the `pki` component is the resource's `backend`, e.g.

        ```sh
        $ pulumi import vault:pkiSecret/backendConfigAcme:BackendConfigAcme example pki/config/acme
        ```

        :param str resource_name: The name of the resource.
        :param BackendConfigAcmeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BackendConfigAcmeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_role_ext_key_usage: Optional[pulumi.Input[_builtins.bool]] = None,
                 allowed_issuers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 default_directory_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
                 eab_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BackendConfigAcmeArgs.__new__(BackendConfigAcmeArgs)

            __props__.__dict__["allow_role_ext_key_usage"] = allow_role_ext_key_usage
            __props__.__dict__["allowed_issuers"] = allowed_issuers
            __props__.__dict__["allowed_roles"] = allowed_roles
            if backend is None and not opts.urn:
                raise TypeError("Missing required property 'backend'")
            __props__.__dict__["backend"] = backend
            __props__.__dict__["default_directory_policy"] = default_directory_policy
            __props__.__dict__["dns_resolver"] = dns_resolver
            __props__.__dict__["eab_policy"] = eab_policy
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["max_ttl"] = max_ttl
            __props__.__dict__["namespace"] = namespace
        super(BackendConfigAcme, __self__).__init__(
            'vault:pkiSecret/backendConfigAcme:BackendConfigAcme',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_role_ext_key_usage: Optional[pulumi.Input[_builtins.bool]] = None,
            allowed_issuers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            backend: Optional[pulumi.Input[_builtins.str]] = None,
            default_directory_policy: Optional[pulumi.Input[_builtins.str]] = None,
            dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
            eab_policy: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None) -> 'BackendConfigAcme':
        """
        Get an existing BackendConfigAcme resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_role_ext_key_usage: Specifies whether the ExtKeyUsage field from a role is used. **Vault 1.14.1+**
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_issuers: Specifies which issuers are allowed for use with ACME.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_roles: Specifies which roles are allowed for use with ACME.
        :param pulumi.Input[_builtins.str] backend: The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.str] default_directory_policy: Specifies the policy to be used for non-role-qualified ACME requests.
               Allowed values are `forbid`, `sign-verbatim`, `role:<role_name>`, `external-policy` or `external-policy:<policy>`.
        :param pulumi.Input[_builtins.str] dns_resolver: DNS resolver to use for domain resolution on this mount.
               Must be in the format `<host>:<port>`, with both parts mandatory.
        :param pulumi.Input[_builtins.str] eab_policy: Specifies the policy to use for external account binding behaviour.
               Allowed values are `not-required`, `new-account-required` or `always-required`.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether ACME is enabled.
        :param pulumi.Input[_builtins.int] max_ttl: The maximum TTL in seconds for certificates issued by ACME. **Vault 1.17.0+**
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BackendConfigAcmeState.__new__(_BackendConfigAcmeState)

        __props__.__dict__["allow_role_ext_key_usage"] = allow_role_ext_key_usage
        __props__.__dict__["allowed_issuers"] = allowed_issuers
        __props__.__dict__["allowed_roles"] = allowed_roles
        __props__.__dict__["backend"] = backend
        __props__.__dict__["default_directory_policy"] = default_directory_policy
        __props__.__dict__["dns_resolver"] = dns_resolver
        __props__.__dict__["eab_policy"] = eab_policy
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["max_ttl"] = max_ttl
        __props__.__dict__["namespace"] = namespace
        return BackendConfigAcme(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowRoleExtKeyUsage")
    def allow_role_ext_key_usage(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Specifies whether the ExtKeyUsage field from a role is used. **Vault 1.14.1+**
        """
        return pulumi.get(self, "allow_role_ext_key_usage")

    @_builtins.property
    @pulumi.getter(name="allowedIssuers")
    def allowed_issuers(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Specifies which issuers are allowed for use with ACME.
        """
        return pulumi.get(self, "allowed_issuers")

    @_builtins.property
    @pulumi.getter(name="allowedRoles")
    def allowed_roles(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Specifies which roles are allowed for use with ACME.
        """
        return pulumi.get(self, "allowed_roles")

    @_builtins.property
    @pulumi.getter
    def backend(self) -> pulumi.Output[_builtins.str]:
        """
        The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @_builtins.property
    @pulumi.getter(name="defaultDirectoryPolicy")
    def default_directory_policy(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the policy to be used for non-role-qualified ACME requests.
        Allowed values are `forbid`, `sign-verbatim`, `role:<role_name>`, `external-policy` or `external-policy:<policy>`.
        """
        return pulumi.get(self, "default_directory_policy")

    @_builtins.property
    @pulumi.getter(name="dnsResolver")
    def dns_resolver(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        DNS resolver to use for domain resolution on this mount.
        Must be in the format `<host>:<port>`, with both parts mandatory.
        """
        return pulumi.get(self, "dns_resolver")

    @_builtins.property
    @pulumi.getter(name="eabPolicy")
    def eab_policy(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the policy to use for external account binding behaviour.
        Allowed values are `not-required`, `new-account-required` or `always-required`.
        """
        return pulumi.get(self, "eab_policy")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Specifies whether ACME is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum TTL in seconds for certificates issued by ACME. **Vault 1.17.0+**
        """
        return pulumi.get(self, "max_ttl")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BackendRoleArgs', 'BackendRole']

@pulumi.input_type
class BackendRoleArgs:
    def __init__(__self__, *,
                 role: pulumi.Input[_builtins.str],
                 application_object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 azure_groups: Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureGroupArgs']]]] = None,
                 azure_roles: Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureRoleArgs']]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 explicit_max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 permanently_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 persist_app: Optional[pulumi.Input[_builtins.bool]] = None,
                 sign_in_audience: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ttl: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a BackendRole resource.
        :param pulumi.Input[_builtins.str] role: Name of the Azure role
        :param pulumi.Input[_builtins.str] application_object_id: Application Object ID for an existing service principal that will
               be used instead of creating dynamic service principals. If present, `azure_roles` and `permanently_delete` will be ignored.
        :param pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureGroupArgs']]] azure_groups: List of Azure groups to be assigned to the generated service principal.
        :param pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureRoleArgs']]] azure_roles: List of Azure roles to be assigned to the generated service principal.
        :param pulumi.Input[_builtins.str] backend: Path to the mounted Azure auth backend
        :param pulumi.Input[_builtins.str] description: Human-friendly description of the mount for the backend.
        :param pulumi.Input[_builtins.str] explicit_max_ttl: Specifies the explicit maximum lifetime of the lease and service principal generated using this role. If not set or set to 0, will use the system default (10 years). Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] max_ttl: Specifies the maximum TTL for service principals generated using this role. Accepts time
               suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine max TTL time.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.bool] permanently_delete: Indicates whether the applications and service principals created by Vault will be permanently
               deleted when the corresponding leases expire. Defaults to `false`. For Vault v1.12+.
        :param pulumi.Input[_builtins.bool] persist_app: If set to true, persists the created service principal and application for the lifetime of the role
        :param pulumi.Input[_builtins.str] sign_in_audience: Specifies the security principal types that are allowed to sign in to the application.
               Valid values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount, PersonalMicrosoftAccount. Requires Vault 1.16+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of Azure tags to attach to an application. Requires Vault 1.16+.
        :param pulumi.Input[_builtins.str] ttl: Specifies the default TTL for service principals generated using this role.
               Accepts time suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine default TTL time.
        """
        pulumi.set(__self__, "role", role)
        if application_object_id is not None:
            pulumi.set(__self__, "application_object_id", application_object_id)
        if azure_groups is not None:
            pulumi.set(__self__, "azure_groups", azure_groups)
        if azure_roles is not None:
            pulumi.set(__self__, "azure_roles", azure_roles)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if explicit_max_ttl is not None:
            pulumi.set(__self__, "explicit_max_ttl", explicit_max_ttl)
        if max_ttl is not None:
            pulumi.set(__self__, "max_ttl", max_ttl)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if permanently_delete is not None:
            pulumi.set(__self__, "permanently_delete", permanently_delete)
        if persist_app is not None:
            pulumi.set(__self__, "persist_app", persist_app)
        if sign_in_audience is not None:
            pulumi.set(__self__, "sign_in_audience", sign_in_audience)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @_builtins.property
    @pulumi.getter
    def role(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the Azure role
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role", value)

    @_builtins.property
    @pulumi.getter(name="applicationObjectId")
    def application_object_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application Object ID for an existing service principal that will
        be used instead of creating dynamic service principals. If present, `azure_roles` and `permanently_delete` will be ignored.
        """
        return pulumi.get(self, "application_object_id")

    @application_object_id.setter
    def application_object_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_object_id", value)

    @_builtins.property
    @pulumi.getter(name="azureGroups")
    def azure_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureGroupArgs']]]]:
        """
        List of Azure groups to be assigned to the generated service principal.
        """
        return pulumi.get(self, "azure_groups")

    @azure_groups.setter
    def azure_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureGroupArgs']]]]):
        pulumi.set(self, "azure_groups", value)

    @_builtins.property
    @pulumi.getter(name="azureRoles")
    def azure_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureRoleArgs']]]]:
        """
        List of Azure roles to be assigned to the generated service principal.
        """
        return pulumi.get(self, "azure_roles")

    @azure_roles.setter
    def azure_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureRoleArgs']]]]):
        pulumi.set(self, "azure_roles", value)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to the mounted Azure auth backend
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Human-friendly description of the mount for the backend.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="explicitMaxTtl")
    def explicit_max_ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the explicit maximum lifetime of the lease and service principal generated using this role. If not set or set to 0, will use the system default (10 years). Requires Vault 1.18+.
        """
        return pulumi.get(self, "explicit_max_ttl")

    @explicit_max_ttl.setter
    def explicit_max_ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "explicit_max_ttl", value)

    @_builtins.property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the maximum TTL for service principals generated using this role. Accepts time
        suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine max TTL time.
        """
        return pulumi.get(self, "max_ttl")

    @max_ttl.setter
    def max_ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "max_ttl", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="permanentlyDelete")
    def permanently_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the applications and service principals created by Vault will be permanently
        deleted when the corresponding leases expire. Defaults to `false`. For Vault v1.12+.
        """
        return pulumi.get(self, "permanently_delete")

    @permanently_delete.setter
    def permanently_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "permanently_delete", value)

    @_builtins.property
    @pulumi.getter(name="persistApp")
    def persist_app(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to true, persists the created service principal and application for the lifetime of the role
        """
        return pulumi.get(self, "persist_app")

    @persist_app.setter
    def persist_app(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "persist_app", value)

    @_builtins.property
    @pulumi.getter(name="signInAudience")
    def sign_in_audience(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the security principal types that are allowed to sign in to the application.
        Valid values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount, PersonalMicrosoftAccount. Requires Vault 1.16+.
        """
        return pulumi.get(self, "sign_in_audience")

    @sign_in_audience.setter
    def sign_in_audience(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_in_audience", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of Azure tags to attach to an application. Requires Vault 1.16+.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the default TTL for service principals generated using this role.
        Accepts time suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine default TTL time.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ttl", value)


@pulumi.input_type
class _BackendRoleState:
    def __init__(__self__, *,
                 application_object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 azure_groups: Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureGroupArgs']]]] = None,
                 azure_roles: Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureRoleArgs']]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 explicit_max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 permanently_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 persist_app: Optional[pulumi.Input[_builtins.bool]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_audience: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ttl: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering BackendRole resources.
        :param pulumi.Input[_builtins.str] application_object_id: Application Object ID for an existing service principal that will
               be used instead of creating dynamic service principals. If present, `azure_roles` and `permanently_delete` will be ignored.
        :param pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureGroupArgs']]] azure_groups: List of Azure groups to be assigned to the generated service principal.
        :param pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureRoleArgs']]] azure_roles: List of Azure roles to be assigned to the generated service principal.
        :param pulumi.Input[_builtins.str] backend: Path to the mounted Azure auth backend
        :param pulumi.Input[_builtins.str] description: Human-friendly description of the mount for the backend.
        :param pulumi.Input[_builtins.str] explicit_max_ttl: Specifies the explicit maximum lifetime of the lease and service principal generated using this role. If not set or set to 0, will use the system default (10 years). Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] max_ttl: Specifies the maximum TTL for service principals generated using this role. Accepts time
               suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine max TTL time.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.bool] permanently_delete: Indicates whether the applications and service principals created by Vault will be permanently
               deleted when the corresponding leases expire. Defaults to `false`. For Vault v1.12+.
        :param pulumi.Input[_builtins.bool] persist_app: If set to true, persists the created service principal and application for the lifetime of the role
        :param pulumi.Input[_builtins.str] role: Name of the Azure role
        :param pulumi.Input[_builtins.str] sign_in_audience: Specifies the security principal types that are allowed to sign in to the application.
               Valid values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount, PersonalMicrosoftAccount. Requires Vault 1.16+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of Azure tags to attach to an application. Requires Vault 1.16+.
        :param pulumi.Input[_builtins.str] ttl: Specifies the default TTL for service principals generated using this role.
               Accepts time suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine default TTL time.
        """
        if application_object_id is not None:
            pulumi.set(__self__, "application_object_id", application_object_id)
        if azure_groups is not None:
            pulumi.set(__self__, "azure_groups", azure_groups)
        if azure_roles is not None:
            pulumi.set(__self__, "azure_roles", azure_roles)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if explicit_max_ttl is not None:
            pulumi.set(__self__, "explicit_max_ttl", explicit_max_ttl)
        if max_ttl is not None:
            pulumi.set(__self__, "max_ttl", max_ttl)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if permanently_delete is not None:
            pulumi.set(__self__, "permanently_delete", permanently_delete)
        if persist_app is not None:
            pulumi.set(__self__, "persist_app", persist_app)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if sign_in_audience is not None:
            pulumi.set(__self__, "sign_in_audience", sign_in_audience)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @_builtins.property
    @pulumi.getter(name="applicationObjectId")
    def application_object_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application Object ID for an existing service principal that will
        be used instead of creating dynamic service principals. If present, `azure_roles` and `permanently_delete` will be ignored.
        """
        return pulumi.get(self, "application_object_id")

    @application_object_id.setter
    def application_object_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_object_id", value)

    @_builtins.property
    @pulumi.getter(name="azureGroups")
    def azure_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureGroupArgs']]]]:
        """
        List of Azure groups to be assigned to the generated service principal.
        """
        return pulumi.get(self, "azure_groups")

    @azure_groups.setter
    def azure_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureGroupArgs']]]]):
        pulumi.set(self, "azure_groups", value)

    @_builtins.property
    @pulumi.getter(name="azureRoles")
    def azure_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureRoleArgs']]]]:
        """
        List of Azure roles to be assigned to the generated service principal.
        """
        return pulumi.get(self, "azure_roles")

    @azure_roles.setter
    def azure_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackendRoleAzureRoleArgs']]]]):
        pulumi.set(self, "azure_roles", value)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to the mounted Azure auth backend
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Human-friendly description of the mount for the backend.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="explicitMaxTtl")
    def explicit_max_ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the explicit maximum lifetime of the lease and service principal generated using this role. If not set or set to 0, will use the system default (10 years). Requires Vault 1.18+.
        """
        return pulumi.get(self, "explicit_max_ttl")

    @explicit_max_ttl.setter
    def explicit_max_ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "explicit_max_ttl", value)

    @_builtins.property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the maximum TTL for service principals generated using this role. Accepts time
        suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine max TTL time.
        """
        return pulumi.get(self, "max_ttl")

    @max_ttl.setter
    def max_ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "max_ttl", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="permanentlyDelete")
    def permanently_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the applications and service principals created by Vault will be permanently
        deleted when the corresponding leases expire. Defaults to `false`. For Vault v1.12+.
        """
        return pulumi.get(self, "permanently_delete")

    @permanently_delete.setter
    def permanently_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "permanently_delete", value)

    @_builtins.property
    @pulumi.getter(name="persistApp")
    def persist_app(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to true, persists the created service principal and application for the lifetime of the role
        """
        return pulumi.get(self, "persist_app")

    @persist_app.setter
    def persist_app(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "persist_app", value)

    @_builtins.property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Azure role
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role", value)

    @_builtins.property
    @pulumi.getter(name="signInAudience")
    def sign_in_audience(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the security principal types that are allowed to sign in to the application.
        Valid values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount, PersonalMicrosoftAccount. Requires Vault 1.16+.
        """
        return pulumi.get(self, "sign_in_audience")

    @sign_in_audience.setter
    def sign_in_audience(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_in_audience", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of Azure tags to attach to an application. Requires Vault 1.16+.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the default TTL for service principals generated using this role.
        Accepts time suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine default TTL time.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ttl", value)


@pulumi.type_token("vault:azure/backendRole:BackendRole")
class BackendRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 azure_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureGroupArgs', 'BackendRoleAzureGroupArgsDict']]]]] = None,
                 azure_roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureRoleArgs', 'BackendRoleAzureRoleArgsDict']]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 explicit_max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 permanently_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 persist_app: Optional[pulumi.Input[_builtins.bool]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_audience: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        azure = vault.azure.Backend("azure",
            subscription_id=subscription_id,
            tenant_id=tenant_id,
            client_secret=client_secret,
            client_id=client_id)
        generated_role = vault.azure.BackendRole("generated_role",
            backend=azure.path,
            role="generated_role",
            sign_in_audience="AzureADMyOrg",
            tags=[
                "team:engineering",
                "environment:development",
            ],
            ttl="300",
            max_ttl="600",
            azure_roles=[{
                "role_name": "Reader",
                "scope": f"/subscriptions/{subscription_id}/resourceGroups/azure-vault-group",
            }])
        existing_object_id = vault.azure.BackendRole("existing_object_id",
            backend=azure.path,
            role="existing_object_id",
            application_object_id="11111111-2222-3333-4444-44444444444",
            ttl="300",
            max_ttl="600")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] application_object_id: Application Object ID for an existing service principal that will
               be used instead of creating dynamic service principals. If present, `azure_roles` and `permanently_delete` will be ignored.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureGroupArgs', 'BackendRoleAzureGroupArgsDict']]]] azure_groups: List of Azure groups to be assigned to the generated service principal.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureRoleArgs', 'BackendRoleAzureRoleArgsDict']]]] azure_roles: List of Azure roles to be assigned to the generated service principal.
        :param pulumi.Input[_builtins.str] backend: Path to the mounted Azure auth backend
        :param pulumi.Input[_builtins.str] description: Human-friendly description of the mount for the backend.
        :param pulumi.Input[_builtins.str] explicit_max_ttl: Specifies the explicit maximum lifetime of the lease and service principal generated using this role. If not set or set to 0, will use the system default (10 years). Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] max_ttl: Specifies the maximum TTL for service principals generated using this role. Accepts time
               suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine max TTL time.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.bool] permanently_delete: Indicates whether the applications and service principals created by Vault will be permanently
               deleted when the corresponding leases expire. Defaults to `false`. For Vault v1.12+.
        :param pulumi.Input[_builtins.bool] persist_app: If set to true, persists the created service principal and application for the lifetime of the role
        :param pulumi.Input[_builtins.str] role: Name of the Azure role
        :param pulumi.Input[_builtins.str] sign_in_audience: Specifies the security principal types that are allowed to sign in to the application.
               Valid values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount, PersonalMicrosoftAccount. Requires Vault 1.16+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of Azure tags to attach to an application. Requires Vault 1.16+.
        :param pulumi.Input[_builtins.str] ttl: Specifies the default TTL for service principals generated using this role.
               Accepts time suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine default TTL time.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BackendRoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        azure = vault.azure.Backend("azure",
            subscription_id=subscription_id,
            tenant_id=tenant_id,
            client_secret=client_secret,
            client_id=client_id)
        generated_role = vault.azure.BackendRole("generated_role",
            backend=azure.path,
            role="generated_role",
            sign_in_audience="AzureADMyOrg",
            tags=[
                "team:engineering",
                "environment:development",
            ],
            ttl="300",
            max_ttl="600",
            azure_roles=[{
                "role_name": "Reader",
                "scope": f"/subscriptions/{subscription_id}/resourceGroups/azure-vault-group",
            }])
        existing_object_id = vault.azure.BackendRole("existing_object_id",
            backend=azure.path,
            role="existing_object_id",
            application_object_id="11111111-2222-3333-4444-44444444444",
            ttl="300",
            max_ttl="600")
        ```

        :param str resource_name: The name of the resource.
        :param BackendRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BackendRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 azure_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureGroupArgs', 'BackendRoleAzureGroupArgsDict']]]]] = None,
                 azure_roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureRoleArgs', 'BackendRoleAzureRoleArgsDict']]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 explicit_max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 permanently_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 persist_app: Optional[pulumi.Input[_builtins.bool]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_audience: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BackendRoleArgs.__new__(BackendRoleArgs)

            __props__.__dict__["application_object_id"] = application_object_id
            __props__.__dict__["azure_groups"] = azure_groups
            __props__.__dict__["azure_roles"] = azure_roles
            __props__.__dict__["backend"] = backend
            __props__.__dict__["description"] = description
            __props__.__dict__["explicit_max_ttl"] = explicit_max_ttl
            __props__.__dict__["max_ttl"] = max_ttl
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["permanently_delete"] = permanently_delete
            __props__.__dict__["persist_app"] = persist_app
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
            __props__.__dict__["sign_in_audience"] = sign_in_audience
            __props__.__dict__["tags"] = tags
            __props__.__dict__["ttl"] = ttl
        super(BackendRole, __self__).__init__(
            'vault:azure/backendRole:BackendRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_object_id: Optional[pulumi.Input[_builtins.str]] = None,
            azure_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureGroupArgs', 'BackendRoleAzureGroupArgsDict']]]]] = None,
            azure_roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureRoleArgs', 'BackendRoleAzureRoleArgsDict']]]]] = None,
            backend: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            explicit_max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
            max_ttl: Optional[pulumi.Input[_builtins.str]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None,
            permanently_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            persist_app: Optional[pulumi.Input[_builtins.bool]] = None,
            role: Optional[pulumi.Input[_builtins.str]] = None,
            sign_in_audience: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ttl: Optional[pulumi.Input[_builtins.str]] = None) -> 'BackendRole':
        """
        Get an existing BackendRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] application_object_id: Application Object ID for an existing service principal that will
               be used instead of creating dynamic service principals. If present, `azure_roles` and `permanently_delete` will be ignored.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureGroupArgs', 'BackendRoleAzureGroupArgsDict']]]] azure_groups: List of Azure groups to be assigned to the generated service principal.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BackendRoleAzureRoleArgs', 'BackendRoleAzureRoleArgsDict']]]] azure_roles: List of Azure roles to be assigned to the generated service principal.
        :param pulumi.Input[_builtins.str] backend: Path to the mounted Azure auth backend
        :param pulumi.Input[_builtins.str] description: Human-friendly description of the mount for the backend.
        :param pulumi.Input[_builtins.str] explicit_max_ttl: Specifies the explicit maximum lifetime of the lease and service principal generated using this role. If not set or set to 0, will use the system default (10 years). Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] max_ttl: Specifies the maximum TTL for service principals generated using this role. Accepts time
               suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine max TTL time.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.bool] permanently_delete: Indicates whether the applications and service principals created by Vault will be permanently
               deleted when the corresponding leases expire. Defaults to `false`. For Vault v1.12+.
        :param pulumi.Input[_builtins.bool] persist_app: If set to true, persists the created service principal and application for the lifetime of the role
        :param pulumi.Input[_builtins.str] role: Name of the Azure role
        :param pulumi.Input[_builtins.str] sign_in_audience: Specifies the security principal types that are allowed to sign in to the application.
               Valid values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount, PersonalMicrosoftAccount. Requires Vault 1.16+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of Azure tags to attach to an application. Requires Vault 1.16+.
        :param pulumi.Input[_builtins.str] ttl: Specifies the default TTL for service principals generated using this role.
               Accepts time suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine default TTL time.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BackendRoleState.__new__(_BackendRoleState)

        __props__.__dict__["application_object_id"] = application_object_id
        __props__.__dict__["azure_groups"] = azure_groups
        __props__.__dict__["azure_roles"] = azure_roles
        __props__.__dict__["backend"] = backend
        __props__.__dict__["description"] = description
        __props__.__dict__["explicit_max_ttl"] = explicit_max_ttl
        __props__.__dict__["max_ttl"] = max_ttl
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["permanently_delete"] = permanently_delete
        __props__.__dict__["persist_app"] = persist_app
        __props__.__dict__["role"] = role
        __props__.__dict__["sign_in_audience"] = sign_in_audience
        __props__.__dict__["tags"] = tags
        __props__.__dict__["ttl"] = ttl
        return BackendRole(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="applicationObjectId")
    def application_object_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Application Object ID for an existing service principal that will
        be used instead of creating dynamic service principals. If present, `azure_roles` and `permanently_delete` will be ignored.
        """
        return pulumi.get(self, "application_object_id")

    @_builtins.property
    @pulumi.getter(name="azureGroups")
    def azure_groups(self) -> pulumi.Output[Optional[Sequence['outputs.BackendRoleAzureGroup']]]:
        """
        List of Azure groups to be assigned to the generated service principal.
        """
        return pulumi.get(self, "azure_groups")

    @_builtins.property
    @pulumi.getter(name="azureRoles")
    def azure_roles(self) -> pulumi.Output[Optional[Sequence['outputs.BackendRoleAzureRole']]]:
        """
        List of Azure roles to be assigned to the generated service principal.
        """
        return pulumi.get(self, "azure_roles")

    @_builtins.property
    @pulumi.getter
    def backend(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Path to the mounted Azure auth backend
        """
        return pulumi.get(self, "backend")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Human-friendly description of the mount for the backend.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="explicitMaxTtl")
    def explicit_max_ttl(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the explicit maximum lifetime of the lease and service principal generated using this role. If not set or set to 0, will use the system default (10 years). Requires Vault 1.18+.
        """
        return pulumi.get(self, "explicit_max_ttl")

    @_builtins.property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the maximum TTL for service principals generated using this role. Accepts time
        suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine max TTL time.
        """
        return pulumi.get(self, "max_ttl")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="permanentlyDelete")
    def permanently_delete(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the applications and service principals created by Vault will be permanently
        deleted when the corresponding leases expire. Defaults to `false`. For Vault v1.12+.
        """
        return pulumi.get(self, "permanently_delete")

    @_builtins.property
    @pulumi.getter(name="persistApp")
    def persist_app(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If set to true, persists the created service principal and application for the lifetime of the role
        """
        return pulumi.get(self, "persist_app")

    @_builtins.property
    @pulumi.getter
    def role(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Azure role
        """
        return pulumi.get(self, "role")

    @_builtins.property
    @pulumi.getter(name="signInAudience")
    def sign_in_audience(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the security principal types that are allowed to sign in to the application.
        Valid values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount, PersonalMicrosoftAccount. Requires Vault 1.16+.
        """
        return pulumi.get(self, "sign_in_audience")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of Azure tags to attach to an application. Requires Vault 1.16+.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the default TTL for service principals generated using this role.
        Accepts time suffixed strings ("1h") or an integer number of seconds. Defaults to the system/engine default TTL time.
        """
        return pulumi.get(self, "ttl")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SyncAssociationMetadataArgs',
    'SyncAssociationMetadataArgsDict',
]

MYPY = False

if not MYPY:
    class SyncAssociationMetadataArgsDict(TypedDict):
        sub_key: NotRequired[pulumi.Input[_builtins.str]]
        """
        Subkey of the associated secret.
        """
        sync_status: NotRequired[pulumi.Input[_builtins.str]]
        """
        A map of sync statuses for each subkey of the associated secret
        (for ex. `{kv_624bea/aws-token/dev: "SYNCED", kv_624bea/aws-token/prod: "SYNCED"}`).
        """
        updated_at: NotRequired[pulumi.Input[_builtins.str]]
        """
        A map of duration strings specifying when each subkey of the associated
        secret was last updated.
        (for ex.
        `{kv_624bea/aws-token/dev: "2024-03-21T12:42:02.558533-07:00",
        kv_624bea/aws-token/prod: "2024-03-21T12:42:02.558533-07:00"}`).
        """
elif False:
    SyncAssociationMetadataArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SyncAssociationMetadataArgs:
    def __init__(__self__, *,
                 sub_key: Optional[pulumi.Input[_builtins.str]] = None,
                 sync_status: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] sub_key: Subkey of the associated secret.
        :param pulumi.Input[_builtins.str] sync_status: A map of sync statuses for each subkey of the associated secret
               (for ex. `{kv_624bea/aws-token/dev: "SYNCED", kv_624bea/aws-token/prod: "SYNCED"}`).
        :param pulumi.Input[_builtins.str] updated_at: A map of duration strings specifying when each subkey of the associated
               secret was last updated.
               (for ex.
               `{kv_624bea/aws-token/dev: "2024-03-21T12:42:02.558533-07:00",
               kv_624bea/aws-token/prod: "2024-03-21T12:42:02.558533-07:00"}`).
        """
        if sub_key is not None:
            pulumi.set(__self__, "sub_key", sub_key)
        if sync_status is not None:
            pulumi.set(__self__, "sync_status", sync_status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="subKey")
    def sub_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subkey of the associated secret.
        """
        return pulumi.get(self, "sub_key")

    @sub_key.setter
    def sub_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sub_key", value)

    @_builtins.property
    @pulumi.getter(name="syncStatus")
    def sync_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A map of sync statuses for each subkey of the associated secret
        (for ex. `{kv_624bea/aws-token/dev: "SYNCED", kv_624bea/aws-token/prod: "SYNCED"}`).
        """
        return pulumi.get(self, "sync_status")

    @sync_status.setter
    def sync_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sync_status", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A map of duration strings specifying when each subkey of the associated
        secret was last updated.
        (for ex.
        `{kv_624bea/aws-token/dev: "2024-03-21T12:42:02.558533-07:00",
        kv_624bea/aws-token/prod: "2024-03-21T12:42:02.558533-07:00"}`).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SecretV2CustomMetadataArgs',
    'SecretV2CustomMetadataArgsDict',
]

MYPY = False

if not MYPY:
    class SecretV2CustomMetadataArgsDict(TypedDict):
        cas_required: NotRequired[pulumi.Input[_builtins.bool]]
        """
        If true, all keys will require the cas parameter to be set on all write requests.
        """
        data: NotRequired[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]
        """
        **Deprecated. Please use new ephemeral resource `kv.SecretV2` to read back
        secret data from Vault**. A mapping whose keys are the top-level data keys returned from
        Vault and whose values are the corresponding values. This map can only represent string data,
        so any non-string values returned from Vault are serialized as JSON.
        """
        delete_version_after: NotRequired[pulumi.Input[_builtins.int]]
        """
        If set, specifies the length of time before a version is deleted.
        """
        max_versions: NotRequired[pulumi.Input[_builtins.int]]
        """
        The number of versions to keep per key.
        """
elif False:
    SecretV2CustomMetadataArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SecretV2CustomMetadataArgs:
    def __init__(__self__, *,
                 cas_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 data: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 delete_version_after: Optional[pulumi.Input[_builtins.int]] = None,
                 max_versions: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.bool] cas_required: If true, all keys will require the cas parameter to be set on all write requests.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] data: **Deprecated. Please use new ephemeral resource `kv.SecretV2` to read back
               secret data from Vault**. A mapping whose keys are the top-level data keys returned from
               Vault and whose values are the corresponding values. This map can only represent string data,
               so any non-string values returned from Vault are serialized as JSON.
        :param pulumi.Input[_builtins.int] delete_version_after: If set, specifies the length of time before a version is deleted.
        :param pulumi.Input[_builtins.int] max_versions: The number of versions to keep per key.
        """
        if cas_required is not None:
            pulumi.set(__self__, "cas_required", cas_required)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if delete_version_after is not None:
            pulumi.set(__self__, "delete_version_after", delete_version_after)
        if max_versions is not None:
            pulumi.set(__self__, "max_versions", max_versions)

    @_builtins.property
    @pulumi.getter(name="casRequired")
    def cas_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, all keys will require the cas parameter to be set on all write requests.
        """
        return pulumi.get(self, "cas_required")

    @cas_required.setter
    def cas_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "cas_required", value)

    @_builtins.property
    @pulumi.getter
    def data(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        **Deprecated. Please use new ephemeral resource `kv.SecretV2` to read back
        secret data from Vault**. A mapping whose keys are the top-level data keys returned from
        Vault and whose values are the corresponding values. This map can only represent string data,
        so any non-string values returned from Vault are serialized as JSON.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "data", value)

    @_builtins.property
    @pulumi.getter(name="deleteVersionAfter")
    def delete_version_after(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        If set, specifies the length of time before a version is deleted.
        """
        return pulumi.get(self, "delete_version_after")

    @delete_version_after.setter
    def delete_version_after(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "delete_version_after", value)

    @_builtins.property
    @pulumi.getter(name="maxVersions")
    def max_versions(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of versions to keep per key.
        """
        return pulumi.get(self, "max_versions")

    @max_versions.setter
    def max_versions(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_versions", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UiCustomMessageArgs', 'UiCustomMessage']

@pulumi.input_type
class UiCustomMessageArgs:
    def __init__(__self__, *,
                 message_base64: pulumi.Input[_builtins.str],
                 start_time: pulumi.Input[_builtins.str],
                 title: pulumi.Input[_builtins.str],
                 authenticated: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_time: Optional[pulumi.Input[_builtins.str]] = None,
                 link: Optional[pulumi.Input['UiCustomMessageLinkArgs']] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a UiCustomMessage resource.
        :param pulumi.Input[_builtins.str] message_base64: The base64-encoded content of the custom message
        :param pulumi.Input[_builtins.str] start_time: The starting time of the active period of the custom message
        :param pulumi.Input[_builtins.str] title: The title of the custom message
        :param pulumi.Input[_builtins.bool] authenticated: A flag indicating whether the custom message is displayed pre-login (false) or post-login (true)
        :param pulumi.Input[_builtins.str] end_time: The ending time of the active period of the custom message. Can be omitted for non-expiring message
        :param pulumi.Input['UiCustomMessageLinkArgs'] link: A block containing a hyperlink associated with the custom message
        :param pulumi.Input[_builtins.str] namespace: Target namespace. (requires Enterprise)
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: A map containing additional options for the custom message
        :param pulumi.Input[_builtins.str] type: The display type of custom message. Allowed values are banner and modal
        """
        pulumi.set(__self__, "message_base64", message_base64)
        pulumi.set(__self__, "start_time", start_time)
        pulumi.set(__self__, "title", title)
        if authenticated is not None:
            pulumi.set(__self__, "authenticated", authenticated)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="messageBase64")
    def message_base64(self) -> pulumi.Input[_builtins.str]:
        """
        The base64-encoded content of the custom message
        """
        return pulumi.get(self, "message_base64")

    @message_base64.setter
    def message_base64(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "message_base64", value)

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Input[_builtins.str]:
        """
        The starting time of the active period of the custom message
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "start_time", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Input[_builtins.str]:
        """
        The title of the custom message
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def authenticated(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A flag indicating whether the custom message is displayed pre-login (false) or post-login (true)
        """
        return pulumi.get(self, "authenticated")

    @authenticated.setter
    def authenticated(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "authenticated", value)

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ending time of the active period of the custom message. Can be omitted for non-expiring message
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "end_time", value)

    @_builtins.property
    @pulumi.getter
    def link(self) -> Optional[pulumi.Input['UiCustomMessageLinkArgs']]:
        """
        A block containing a hyperlink associated with the custom message
        """
        return pulumi.get(self, "link")

    @link.setter
    def link(self, value: Optional[pulumi.Input['UiCustomMessageLinkArgs']]):
        pulumi.set(self, "link", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Target namespace. (requires Enterprise)
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map containing additional options for the custom message
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "options", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display type of custom message. Allowed values are banner and modal
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _UiCustomMessageState:
    def __init__(__self__, *,
                 authenticated: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_time: Optional[pulumi.Input[_builtins.str]] = None,
                 link: Optional[pulumi.Input['UiCustomMessageLinkArgs']] = None,
                 message_base64: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 start_time: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering UiCustomMessage resources.
        :param pulumi.Input[_builtins.bool] authenticated: A flag indicating whether the custom message is displayed pre-login (false) or post-login (true)
        :param pulumi.Input[_builtins.str] end_time: The ending time of the active period of the custom message. Can be omitted for non-expiring message
        :param pulumi.Input['UiCustomMessageLinkArgs'] link: A block containing a hyperlink associated with the custom message
        :param pulumi.Input[_builtins.str] message_base64: The base64-encoded content of the custom message
        :param pulumi.Input[_builtins.str] namespace: Target namespace. (requires Enterprise)
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: A map containing additional options for the custom message
        :param pulumi.Input[_builtins.str] start_time: The starting time of the active period of the custom message
        :param pulumi.Input[_builtins.str] title: The title of the custom message
        :param pulumi.Input[_builtins.str] type: The display type of custom message. Allowed values are banner and modal
        """
        if authenticated is not None:
            pulumi.set(__self__, "authenticated", authenticated)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if message_base64 is not None:
            pulumi.set(__self__, "message_base64", message_base64)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def authenticated(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A flag indicating whether the custom message is displayed pre-login (false) or post-login (true)
        """
        return pulumi.get(self, "authenticated")

    @authenticated.setter
    def authenticated(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "authenticated", value)

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ending time of the active period of the custom message. Can be omitted for non-expiring message
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "end_time", value)

    @_builtins.property
    @pulumi.getter
    def link(self) -> Optional[pulumi.Input['UiCustomMessageLinkArgs']]:
        """
        A block containing a hyperlink associated with the custom message
        """
        return pulumi.get(self, "link")

    @link.setter
    def link(self, value: Optional[pulumi.Input['UiCustomMessageLinkArgs']]):
        pulumi.set(self, "link", value)

    @_builtins.property
    @pulumi.getter(name="messageBase64")
    def message_base64(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The base64-encoded content of the custom message
        """
        return pulumi.get(self, "message_base64")

    @message_base64.setter
    def message_base64(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "message_base64", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Target namespace. (requires Enterprise)
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map containing additional options for the custom message
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "options", value)

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The starting time of the active period of the custom message
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "start_time", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The title of the custom message
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display type of custom message. Allowed values are banner and modal
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("vault:config/uiCustomMessage:UiCustomMessage")
class UiCustomMessage(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authenticated: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_time: Optional[pulumi.Input[_builtins.str]] = None,
                 link: Optional[pulumi.Input[Union['UiCustomMessageLinkArgs', 'UiCustomMessageLinkArgsDict']]] = None,
                 message_base64: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 start_time: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a UiCustomMessage resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] authenticated: A flag indicating whether the custom message is displayed pre-login (false) or post-login (true)
        :param pulumi.Input[_builtins.str] end_time: The ending time of the active period of the custom message. Can be omitted for non-expiring message
        :param pulumi.Input[Union['UiCustomMessageLinkArgs', 'UiCustomMessageLinkArgsDict']] link: A block containing a hyperlink associated with the custom message
        :param pulumi.Input[_builtins.str] message_base64: The base64-encoded content of the custom message
        :param pulumi.Input[_builtins.str] namespace: Target namespace. (requires Enterprise)
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: A map containing additional options for the custom message
        :param pulumi.Input[_builtins.str] start_time: The starting time of the active period of the custom message
        :param pulumi.Input[_builtins.str] title: The title of the custom message
        :param pulumi.Input[_builtins.str] type: The display type of custom message. Allowed values are banner and modal
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UiCustomMessageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a UiCustomMessage resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param UiCustomMessageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UiCustomMessageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authenticated: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_time: Optional[pulumi.Input[_builtins.str]] = None,
                 link: Optional[pulumi.Input[Union['UiCustomMessageLinkArgs', 'UiCustomMessageLinkArgsDict']]] = None,
                 message_base64: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 start_time: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UiCustomMessageArgs.__new__(UiCustomMessageArgs)

            __props__.__dict__["authenticated"] = authenticated
            __props__.__dict__["end_time"] = end_time
            __props__.__dict__["link"] = link
            if message_base64 is None and not opts.urn:
                raise TypeError("Missing required property 'message_base64'")
            __props__.__dict__["message_base64"] = message_base64
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["options"] = options
            if start_time is None and not opts.urn:
                raise TypeError("Missing required property 'start_time'")
            __props__.__dict__["start_time"] = start_time
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            __props__.__dict__["type"] = type
        super(UiCustomMessage, __self__).__init__(
            'vault:config/uiCustomMessage:UiCustomMessage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authenticated: Optional[pulumi.Input[_builtins.bool]] = None,
            end_time: Optional[pulumi.Input[_builtins.str]] = None,
            link: Optional[pulumi.Input[Union['UiCustomMessageLinkArgs', 'UiCustomMessageLinkArgsDict']]] = None,
            message_base64: Optional[pulumi.Input[_builtins.str]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None,
            options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            start_time: Optional[pulumi.Input[_builtins.str]] = None,
            title: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'UiCustomMessage':
        """
        Get an existing UiCustomMessage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] authenticated: A flag indicating whether the custom message is displayed pre-login (false) or post-login (true)
        :param pulumi.Input[_builtins.str] end_time: The ending time of the active period of the custom message. Can be omitted for non-expiring message
        :param pulumi.Input[Union['UiCustomMessageLinkArgs', 'UiCustomMessageLinkArgsDict']] link: A block containing a hyperlink associated with the custom message
        :param pulumi.Input[_builtins.str] message_base64: The base64-encoded content of the custom message
        :param pulumi.Input[_builtins.str] namespace: Target namespace. (requires Enterprise)
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: A map containing additional options for the custom message
        :param pulumi.Input[_builtins.str] start_time: The starting time of the active period of the custom message
        :param pulumi.Input[_builtins.str] title: The title of the custom message
        :param pulumi.Input[_builtins.str] type: The display type of custom message. Allowed values are banner and modal
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UiCustomMessageState.__new__(_UiCustomMessageState)

        __props__.__dict__["authenticated"] = authenticated
        __props__.__dict__["end_time"] = end_time
        __props__.__dict__["link"] = link
        __props__.__dict__["message_base64"] = message_base64
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["options"] = options
        __props__.__dict__["start_time"] = start_time
        __props__.__dict__["title"] = title
        __props__.__dict__["type"] = type
        return UiCustomMessage(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def authenticated(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        A flag indicating whether the custom message is displayed pre-login (false) or post-login (true)
        """
        return pulumi.get(self, "authenticated")

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ending time of the active period of the custom message. Can be omitted for non-expiring message
        """
        return pulumi.get(self, "end_time")

    @_builtins.property
    @pulumi.getter
    def link(self) -> pulumi.Output[Optional['outputs.UiCustomMessageLink']]:
        """
        A block containing a hyperlink associated with the custom message
        """
        return pulumi.get(self, "link")

    @_builtins.property
    @pulumi.getter(name="messageBase64")
    def message_base64(self) -> pulumi.Output[_builtins.str]:
        """
        The base64-encoded content of the custom message
        """
        return pulumi.get(self, "message_base64")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Target namespace. (requires Enterprise)
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter
    def options(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A map containing additional options for the custom message
        """
        return pulumi.get(self, "options")

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Output[_builtins.str]:
        """
        The starting time of the active period of the custom message
        """
        return pulumi.get(self, "start_time")

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Output[_builtins.str]:
        """
        The title of the custom message
        """
        return pulumi.get(self, "title")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The display type of custom message. Allowed values are banner and modal
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetBackendIssuerResult',
    'AwaitableGetBackendIssuerResult',
    'get_backend_issuer',
    'get_backend_issuer_output',
]

@pulumi.output_type
class GetBackendIssuerResult:
    """
    A collection of values returned by getBackendIssuer.
    """
    def __init__(__self__, backend=None, ca_chains=None, certificate=None, disable_critical_extension_checks=None, disable_name_checks=None, disable_name_constraint_checks=None, disable_path_length_checks=None, id=None, issuer_id=None, issuer_name=None, issuer_ref=None, key_id=None, leaf_not_after_behavior=None, manual_chains=None, namespace=None, usage=None):
        if backend and not isinstance(backend, str):
            raise TypeError("Expected argument 'backend' to be a str")
        pulumi.set(__self__, "backend", backend)
        if ca_chains and not isinstance(ca_chains, list):
            raise TypeError("Expected argument 'ca_chains' to be a list")
        pulumi.set(__self__, "ca_chains", ca_chains)
        if certificate and not isinstance(certificate, str):
            raise TypeError("Expected argument 'certificate' to be a str")
        pulumi.set(__self__, "certificate", certificate)
        if disable_critical_extension_checks and not isinstance(disable_critical_extension_checks, bool):
            raise TypeError("Expected argument 'disable_critical_extension_checks' to be a bool")
        pulumi.set(__self__, "disable_critical_extension_checks", disable_critical_extension_checks)
        if disable_name_checks and not isinstance(disable_name_checks, bool):
            raise TypeError("Expected argument 'disable_name_checks' to be a bool")
        pulumi.set(__self__, "disable_name_checks", disable_name_checks)
        if disable_name_constraint_checks and not isinstance(disable_name_constraint_checks, bool):
            raise TypeError("Expected argument 'disable_name_constraint_checks' to be a bool")
        pulumi.set(__self__, "disable_name_constraint_checks", disable_name_constraint_checks)
        if disable_path_length_checks and not isinstance(disable_path_length_checks, bool):
            raise TypeError("Expected argument 'disable_path_length_checks' to be a bool")
        pulumi.set(__self__, "disable_path_length_checks", disable_path_length_checks)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issuer_id and not isinstance(issuer_id, str):
            raise TypeError("Expected argument 'issuer_id' to be a str")
        pulumi.set(__self__, "issuer_id", issuer_id)
        if issuer_name and not isinstance(issuer_name, str):
            raise TypeError("Expected argument 'issuer_name' to be a str")
        pulumi.set(__self__, "issuer_name", issuer_name)
        if issuer_ref and not isinstance(issuer_ref, str):
            raise TypeError("Expected argument 'issuer_ref' to be a str")
        pulumi.set(__self__, "issuer_ref", issuer_ref)
        if key_id and not isinstance(key_id, str):
            raise TypeError("Expected argument 'key_id' to be a str")
        pulumi.set(__self__, "key_id", key_id)
        if leaf_not_after_behavior and not isinstance(leaf_not_after_behavior, str):
            raise TypeError("Expected argument 'leaf_not_after_behavior' to be a str")
        pulumi.set(__self__, "leaf_not_after_behavior", leaf_not_after_behavior)
        if manual_chains and not isinstance(manual_chains, list):
            raise TypeError("Expected argument 'manual_chains' to be a list")
        pulumi.set(__self__, "manual_chains", manual_chains)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if usage and not isinstance(usage, str):
            raise TypeError("Expected argument 'usage' to be a str")
        pulumi.set(__self__, "usage", usage)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> _builtins.str:
        return pulumi.get(self, "backend")

    @_builtins.property
    @pulumi.getter(name="caChains")
    def ca_chains(self) -> Sequence[_builtins.str]:
        """
        The CA chain as a list of format specific certificates.
        """
        return pulumi.get(self, "ca_chains")

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> _builtins.str:
        """
        Certificate associated with this issuer.
        """
        return pulumi.get(self, "certificate")

    @_builtins.property
    @pulumi.getter(name="disableCriticalExtensionChecks")
    def disable_critical_extension_checks(self) -> Optional[_builtins.bool]:
        """
        This determines whether this
        issuer is able to issue certificates where the chain of trust (including the
        issued certificate) contain critical extensions not processed by Vault.
        """
        return pulumi.get(self, "disable_critical_extension_checks")

    @_builtins.property
    @pulumi.getter(name="disableNameChecks")
    def disable_name_checks(self) -> Optional[_builtins.bool]:
        """
        This determines whether this issuer is able
        to issue certificates where the chain of trust (including the final issued
        certificate) contains a link in which the subject of the issuing certificate
        does not match the named issuer of the certificate it signed.
        """
        return pulumi.get(self, "disable_name_checks")

    @_builtins.property
    @pulumi.getter(name="disableNameConstraintChecks")
    def disable_name_constraint_checks(self) -> Optional[_builtins.bool]:
        """
        This determines whether this
        issuer is able to issue certificates where the chain of trust (including the
        final issued certificate) violates the name constraints critical extension of
        one of the issuer certificates in the chain.
        """
        return pulumi.get(self, "disable_name_constraint_checks")

    @_builtins.property
    @pulumi.getter(name="disablePathLengthChecks")
    def disable_path_length_checks(self) -> Optional[_builtins.bool]:
        """
        This determines whether this issuer
        is able to issue certificates where the chain of trust (including the final
        issued certificate) is longer than allowed by a certificate authority in that
        chain.
        """
        return pulumi.get(self, "disable_path_length_checks")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="issuerId")
    def issuer_id(self) -> _builtins.str:
        """
        ID of the issuer.
        """
        return pulumi.get(self, "issuer_id")

    @_builtins.property
    @pulumi.getter(name="issuerName")
    def issuer_name(self) -> _builtins.str:
        """
        Name of the issuer.
        """
        return pulumi.get(self, "issuer_name")

    @_builtins.property
    @pulumi.getter(name="issuerRef")
    def issuer_ref(self) -> _builtins.str:
        return pulumi.get(self, "issuer_ref")

    @_builtins.property
    @pulumi.getter(name="keyId")
    def key_id(self) -> _builtins.str:
        """
        ID of the key used by the issuer.
        """
        return pulumi.get(self, "key_id")

    @_builtins.property
    @pulumi.getter(name="leafNotAfterBehavior")
    def leaf_not_after_behavior(self) -> _builtins.str:
        """
        Behavior of a leaf's NotAfter field during issuance.
        """
        return pulumi.get(self, "leaf_not_after_behavior")

    @_builtins.property
    @pulumi.getter(name="manualChains")
    def manual_chains(self) -> Sequence[_builtins.str]:
        """
        Chain of issuer references to build this issuer's computed 
        CAChain field from, when non-empty.
        """
        return pulumi.get(self, "manual_chains")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter
    def usage(self) -> _builtins.str:
        """
        Allowed usages for this issuer.
        """
        return pulumi.get(self, "usage")


class AwaitableGetBackendIssuerResult(GetBackendIssuerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackendIssuerResult(
            backend=self.backend,
            ca_chains=self.ca_chains,
            certificate=self.certificate,
            disable_critical_extension_checks=self.disable_critical_extension_checks,
            disable_name_checks=self.disable_name_checks,
            disable_name_constraint_checks=self.disable_name_constraint_checks,
            disable_path_length_checks=self.disable_path_length_checks,
            id=self.id,
            issuer_id=self.issuer_id,
            issuer_name=self.issuer_name,
            issuer_ref=self.issuer_ref,
            key_id=self.key_id,
            leaf_not_after_behavior=self.leaf_not_after_behavior,
            manual_chains=self.manual_chains,
            namespace=self.namespace,
            usage=self.usage)


def get_backend_issuer(backend: Optional[_builtins.str] = None,
                       disable_critical_extension_checks: Optional[_builtins.bool] = None,
                       disable_name_checks: Optional[_builtins.bool] = None,
                       disable_name_constraint_checks: Optional[_builtins.bool] = None,
                       disable_path_length_checks: Optional[_builtins.bool] = None,
                       issuer_ref: Optional[_builtins.str] = None,
                       namespace: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackendIssuerResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    pki = vault.Mount("pki",
        path="pki",
        type="pki",
        description="PKI secret engine mount")
    root = vault.pkisecret.SecretBackendRootCert("root",
        backend=pki.path,
        type="internal",
        common_name="example",
        ttl="86400",
        issuer_name="example")
    example = root.issuer_id.apply(lambda issuer_id: vault.pkiSecret.get_backend_issuer_output(backend=root.path,
        issuer_ref=issuer_id))
    ```


    :param _builtins.str backend: The path to the PKI secret backend to
           read the issuer from, with no leading or trailing `/`s.
    :param _builtins.bool disable_critical_extension_checks: This determines whether this
           issuer is able to issue certificates where the chain of trust (including the
           issued certificate) contain critical extensions not processed by Vault.
    :param _builtins.bool disable_name_checks: This determines whether this issuer is able
           to issue certificates where the chain of trust (including the final issued
           certificate) contains a link in which the subject of the issuing certificate
           does not match the named issuer of the certificate it signed.
    :param _builtins.bool disable_name_constraint_checks: This determines whether this
           issuer is able to issue certificates where the chain of trust (including the
           final issued certificate) violates the name constraints critical extension of
           one of the issuer certificates in the chain.
    :param _builtins.bool disable_path_length_checks: This determines whether this issuer
           is able to issue certificates where the chain of trust (including the final
           issued certificate) is longer than allowed by a certificate authority in that
           chain.
    :param _builtins.str issuer_ref: Reference to an existing issuer.
    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['backend'] = backend
    __args__['disableCriticalExtensionChecks'] = disable_critical_extension_checks
    __args__['disableNameChecks'] = disable_name_checks
    __args__['disableNameConstraintChecks'] = disable_name_constraint_checks
    __args__['disablePathLengthChecks'] = disable_path_length_checks
    __args__['issuerRef'] = issuer_ref
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:pkiSecret/getBackendIssuer:getBackendIssuer', __args__, opts=opts, typ=GetBackendIssuerResult).value

    return AwaitableGetBackendIssuerResult(
        backend=pulumi.get(__ret__, 'backend'),
        ca_chains=pulumi.get(__ret__, 'ca_chains'),
        certificate=pulumi.get(__ret__, 'certificate'),
        disable_critical_extension_checks=pulumi.get(__ret__, 'disable_critical_extension_checks'),
        disable_name_checks=pulumi.get(__ret__, 'disable_name_checks'),
        disable_name_constraint_checks=pulumi.get(__ret__, 'disable_name_constraint_checks'),
        disable_path_length_checks=pulumi.get(__ret__, 'disable_path_length_checks'),
        id=pulumi.get(__ret__, 'id'),
        issuer_id=pulumi.get(__ret__, 'issuer_id'),
        issuer_name=pulumi.get(__ret__, 'issuer_name'),
        issuer_ref=pulumi.get(__ret__, 'issuer_ref'),
        key_id=pulumi.get(__ret__, 'key_id'),
        leaf_not_after_behavior=pulumi.get(__ret__, 'leaf_not_after_behavior'),
        manual_chains=pulumi.get(__ret__, 'manual_chains'),
        namespace=pulumi.get(__ret__, 'namespace'),
        usage=pulumi.get(__ret__, 'usage'))
def get_backend_issuer_output(backend: Optional[pulumi.Input[_builtins.str]] = None,
                              disable_critical_extension_checks: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                              disable_name_checks: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                              disable_name_constraint_checks: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                              disable_path_length_checks: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                              issuer_ref: Optional[pulumi.Input[_builtins.str]] = None,
                              namespace: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBackendIssuerResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    pki = vault.Mount("pki",
        path="pki",
        type="pki",
        description="PKI secret engine mount")
    root = vault.pkisecret.SecretBackendRootCert("root",
        backend=pki.path,
        type="internal",
        common_name="example",
        ttl="86400",
        issuer_name="example")
    example = root.issuer_id.apply(lambda issuer_id: vault.pkiSecret.get_backend_issuer_output(backend=root.path,
        issuer_ref=issuer_id))
    ```


    :param _builtins.str backend: The path to the PKI secret backend to
           read the issuer from, with no leading or trailing `/`s.
    :param _builtins.bool disable_critical_extension_checks: This determines whether this
           issuer is able to issue certificates where the chain of trust (including the
           issued certificate) contain critical extensions not processed by Vault.
    :param _builtins.bool disable_name_checks: This determines whether this issuer is able
           to issue certificates where the chain of trust (including the final issued
           certificate) contains a link in which the subject of the issuing certificate
           does not match the named issuer of the certificate it signed.
    :param _builtins.bool disable_name_constraint_checks: This determines whether this
           issuer is able to issue certificates where the chain of trust (including the
           final issued certificate) violates the name constraints critical extension of
           one of the issuer certificates in the chain.
    :param _builtins.bool disable_path_length_checks: This determines whether this issuer
           is able to issue certificates where the chain of trust (including the final
           issued certificate) is longer than allowed by a certificate authority in that
           chain.
    :param _builtins.str issuer_ref: Reference to an existing issuer.
    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['backend'] = backend
    __args__['disableCriticalExtensionChecks'] = disable_critical_extension_checks
    __args__['disableNameChecks'] = disable_name_checks
    __args__['disableNameConstraintChecks'] = disable_name_constraint_checks
    __args__['disablePathLengthChecks'] = disable_path_length_checks
    __args__['issuerRef'] = issuer_ref
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vault:pkiSecret/getBackendIssuer:getBackendIssuer', __args__, opts=opts, typ=GetBackendIssuerResult)
    return __ret__.apply(lambda __response__: GetBackendIssuerResult(
        backend=pulumi.get(__response__, 'backend'),
        ca_chains=pulumi.get(__response__, 'ca_chains'),
        certificate=pulumi.get(__response__, 'certificate'),
        disable_critical_extension_checks=pulumi.get(__response__, 'disable_critical_extension_checks'),
        disable_name_checks=pulumi.get(__response__, 'disable_name_checks'),
        disable_name_constraint_checks=pulumi.get(__response__, 'disable_name_constraint_checks'),
        disable_path_length_checks=pulumi.get(__response__, 'disable_path_length_checks'),
        id=pulumi.get(__response__, 'id'),
        issuer_id=pulumi.get(__response__, 'issuer_id'),
        issuer_name=pulumi.get(__response__, 'issuer_name'),
        issuer_ref=pulumi.get(__response__, 'issuer_ref'),
        key_id=pulumi.get(__response__, 'key_id'),
        leaf_not_after_behavior=pulumi.get(__response__, 'leaf_not_after_behavior'),
        manual_chains=pulumi.get(__response__, 'manual_chains'),
        namespace=pulumi.get(__response__, 'namespace'),
        usage=pulumi.get(__response__, 'usage')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBackendConfigEstResult',
    'AwaitableGetBackendConfigEstResult',
    'get_backend_config_est',
    'get_backend_config_est_output',
]

@pulumi.output_type
class GetBackendConfigEstResult:
    """
    A collection of values returned by getBackendConfigEst.
    """
    def __init__(__self__, audit_fields=None, authenticators=None, backend=None, default_mount=None, default_path_policy=None, enable_sentinel_parsing=None, enabled=None, id=None, label_to_path_policy=None, last_updated=None, namespace=None):
        if audit_fields and not isinstance(audit_fields, list):
            raise TypeError("Expected argument 'audit_fields' to be a list")
        pulumi.set(__self__, "audit_fields", audit_fields)
        if authenticators and not isinstance(authenticators, list):
            raise TypeError("Expected argument 'authenticators' to be a list")
        pulumi.set(__self__, "authenticators", authenticators)
        if backend and not isinstance(backend, str):
            raise TypeError("Expected argument 'backend' to be a str")
        pulumi.set(__self__, "backend", backend)
        if default_mount and not isinstance(default_mount, bool):
            raise TypeError("Expected argument 'default_mount' to be a bool")
        pulumi.set(__self__, "default_mount", default_mount)
        if default_path_policy and not isinstance(default_path_policy, str):
            raise TypeError("Expected argument 'default_path_policy' to be a str")
        pulumi.set(__self__, "default_path_policy", default_path_policy)
        if enable_sentinel_parsing and not isinstance(enable_sentinel_parsing, bool):
            raise TypeError("Expected argument 'enable_sentinel_parsing' to be a bool")
        pulumi.set(__self__, "enable_sentinel_parsing", enable_sentinel_parsing)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label_to_path_policy and not isinstance(label_to_path_policy, dict):
            raise TypeError("Expected argument 'label_to_path_policy' to be a dict")
        pulumi.set(__self__, "label_to_path_policy", label_to_path_policy)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)

    @_builtins.property
    @pulumi.getter(name="auditFields")
    def audit_fields(self) -> Sequence[_builtins.str]:
        """
        Fields parsed from the CSR that appear in the audit and can be used by sentinel policies.
        """
        return pulumi.get(self, "audit_fields")

    @_builtins.property
    @pulumi.getter
    def authenticators(self) -> Sequence['outputs.GetBackendConfigEstAuthenticatorResult']:
        """
        Lists the mount accessors EST should delegate authentication requests towards (see below for nested schema).
        """
        return pulumi.get(self, "authenticators")

    @_builtins.property
    @pulumi.getter
    def backend(self) -> _builtins.str:
        return pulumi.get(self, "backend")

    @_builtins.property
    @pulumi.getter(name="defaultMount")
    def default_mount(self) -> _builtins.bool:
        """
        If set, this mount is registered as the default `.well-known/est` URL path. Only a single mount can enable this across a Vault cluster.
        """
        return pulumi.get(self, "default_mount")

    @_builtins.property
    @pulumi.getter(name="defaultPathPolicy")
    def default_path_policy(self) -> _builtins.str:
        """
        Required to be set if default_mount is enabled. Specifies the behavior for requests using the default EST label. Can be sign-verbatim or a role given by role:<role_name>.
        """
        return pulumi.get(self, "default_path_policy")

    @_builtins.property
    @pulumi.getter(name="enableSentinelParsing")
    def enable_sentinel_parsing(self) -> _builtins.bool:
        """
        If set, parse out fields from the provided CSR making them available for Sentinel policies.
        """
        return pulumi.get(self, "enable_sentinel_parsing")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Specifies whether EST is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="labelToPathPolicy")
    def label_to_path_policy(self) -> Mapping[str, _builtins.str]:
        """
        A pairing of an EST label with the redirected behavior for requests hitting that role. The path policy can be sign-verbatim or a role given by role:<role_name>. Labels must be unique across Vault cluster, and will register .well-known/est/<label> URL paths.
        """
        return pulumi.get(self, "label_to_path_policy")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        A read-only timestamp representing the last time the configuration was updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "namespace")


class AwaitableGetBackendConfigEstResult(GetBackendConfigEstResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackendConfigEstResult(
            audit_fields=self.audit_fields,
            authenticators=self.authenticators,
            backend=self.backend,
            default_mount=self.default_mount,
            default_path_policy=self.default_path_policy,
            enable_sentinel_parsing=self.enable_sentinel_parsing,
            enabled=self.enabled,
            id=self.id,
            label_to_path_policy=self.label_to_path_policy,
            last_updated=self.last_updated,
            namespace=self.namespace)


def get_backend_config_est(backend: Optional[_builtins.str] = None,
                           namespace: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackendConfigEstResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    pki = vault.Mount("pki",
        path="pki",
        type="pki",
        description="PKI secret engine mount")
    est_config = vault.pkiSecret.get_backend_config_est_output(backend=pki.path)
    ```


    :param _builtins.str backend: The path to the PKI secret backend to
           read the EST configuration from, with no leading or trailing `/`s.
    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['backend'] = backend
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:pkiSecret/getBackendConfigEst:getBackendConfigEst', __args__, opts=opts, typ=GetBackendConfigEstResult).value

    return AwaitableGetBackendConfigEstResult(
        audit_fields=pulumi.get(__ret__, 'audit_fields'),
        authenticators=pulumi.get(__ret__, 'authenticators'),
        backend=pulumi.get(__ret__, 'backend'),
        default_mount=pulumi.get(__ret__, 'default_mount'),
        default_path_policy=pulumi.get(__ret__, 'default_path_policy'),
        enable_sentinel_parsing=pulumi.get(__ret__, 'enable_sentinel_parsing'),
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        label_to_path_policy=pulumi.get(__ret__, 'label_to_path_policy'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        namespace=pulumi.get(__ret__, 'namespace'))
def get_backend_config_est_output(backend: Optional[pulumi.Input[_builtins.str]] = None,
                                  namespace: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBackendConfigEstResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    pki = vault.Mount("pki",
        path="pki",
        type="pki",
        description="PKI secret engine mount")
    est_config = vault.pkiSecret.get_backend_config_est_output(backend=pki.path)
    ```


    :param _builtins.str backend: The path to the PKI secret backend to
           read the EST configuration from, with no leading or trailing `/`s.
    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['backend'] = backend
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vault:pkiSecret/getBackendConfigEst:getBackendConfigEst', __args__, opts=opts, typ=GetBackendConfigEstResult)
    return __ret__.apply(lambda __response__: GetBackendConfigEstResult(
        audit_fields=pulumi.get(__response__, 'audit_fields'),
        authenticators=pulumi.get(__response__, 'authenticators'),
        backend=pulumi.get(__response__, 'backend'),
        default_mount=pulumi.get(__response__, 'default_mount'),
        default_path_policy=pulumi.get(__response__, 'default_path_policy'),
        enable_sentinel_parsing=pulumi.get(__response__, 'enable_sentinel_parsing'),
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        label_to_path_policy=pulumi.get(__response__, 'label_to_path_policy'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        namespace=pulumi.get(__response__, 'namespace')))
